<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShowPopup"
    round
    closeable
    position="top"
    :style="{ height: '42%' }"
  >
    <div class="query-search-popup">
      <div class="title">人员查询</div>
      <van-form label-width="80px">
        <van-field
          v-model="customQueryPrams.account"
          name="账号名"
          label="账号名"
          placeholder="请输入账号名"
          clearable
        />
        <van-field
          v-model="customQueryPrams.fullname"
          name="人员姓名"
          label="人员姓名"
          placeholder="请输入人员姓名"
          clearable
        />
        <van-field
          v-model="customQueryPrams.mobile"
          name="联系电话"
          label="联系电话"
          placeholder="请输入联系电话"
          clearable
        />

        <div class="search-btn">
          <van-button class="btn-left" block type="info" native-type="button" @click="searchData">
            查询
          </van-button>
          <van-button class="btn-right" block plain type="info" native-type="button" @click="resetData">
            重置
          </van-button>
        </div>
      </van-form>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'

export default {
  name: 'QuerySearchPopup', // 排查单位查询-筛选弹层
  props: {
    // 是否展示弹层
    querySearchPopup: {
      default: false,
      type: Boolean
    },
    // 查询对象
    customQueryPrams: {
      default: () => ({
        account: '',  // 账号名
        fullname: '', // 人员姓名
        mobile: '', // 联系电话
        DEM_ID_: '' // 组织ID（部门ID）
      }),
      type: Object
    }
  },
  data() {
    return {
      unitTypePicker: false // 受检单位类型选择显示
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.querySearchPopup
      },
      set(val) {
        this.$emit('update:querySearchPopup', val)
      }
    }
  },
  methods: {
    moment,

    // 查询列表数据（校验成功后）
    searchData() {
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    },

    // 重置数据
    resetData() {
      /*
      * 重置数据，从父组件找到 “customQueryPrams对象” 的原始结构
      * 并还原表单原始状态
      * */
      Object.keys(this.customQueryPrams).forEach(key => {
        this.customQueryPrams[key] = this.$parent.$options.data().customQueryPrams[key]
      })
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    }
  }
}
</script>

<style lang="scss" scoped>
.query-search-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  .title {
    width: 100%;
    box-sizing: border-box;
    padding: 130px 0 100px 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 80px;
  }

  .van-form {
    flex: 1;
    position: relative;

    .search-btn {
      display: flex;
      position: absolute;
      bottom: 5%;
      width: 80%;
      transform: translateX(-50%);
      left: 50%;

      .van-button {

        &.btn-left {
          border-radius: 999px 0 0 999px;
        }

        &.btn-right {
          border-radius: 0 999px 999px 0;
        }

        .van-button__text {
          font-size: 65px;
        }
      }


    }
  }

}
</style>

